# Sources

```{eval-rst}

.. automodule:: kaskada.sources

    .. autosummary::
        :toctree: apidocs/sources

        Source
        CsvString
        JsonlFile
        JsonlString
        Pandas
        Parquet
        PyDict
```